# vim: set sw=4 ts=4 et:
#
# spec file for package extractor
#
# Copyright (c) 2010 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define soname	        3
%define common_soname   1

Name:           extractor
Version:        1.2
Release:        1.4
License:        GPL-2.0+
Summary:        Library to Extract Metadata from Files
Url:            http://www.gnu.org/software/libextractor/
Group:          System/Libraries
Source:         ftp://ftp.gnu.org/gnu/libextractor/libextractor-%{version}.tar.gz
BuildRequires:  file-devel
BuildRequires:  flac-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  gtk3-devel
BuildRequires:  libarchive-devel
BuildRequires:  libbz2-devel
BuildRequires:  libexiv2-devel
#BuildRequires:  libffmpeg-devel
BuildRequires:  libgsf-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmp4v2-devel
BuildRequires:  libmpeg2-devel
BuildRequires:  libpoppler-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libvorbis-devel
BuildRequires:  pkg-config
BuildRequires:  rpm-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(gtk+-2.0)
Provides:       libextractor = 0.5.3
Obsoletes:      libextractor < 0.5.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post):	info
Requires(postun):	info

%description
Using libextractor, you can extract metadata from files of arbitrary
types. Supported file formats include HTML, PDF, DVI, PS, MP3, OGG,
WAV, JPEG, GIF, PNG, TIFF, RPM, ZIP, TAR, ELF, REAL, RIFF (AVI), MPEG,
QT, and ASF. Also, various additional MIME types are detected.

This release adds support for Adobe Flash (FLV) and Free Lossless Audio
Codec (FLAC) files. The quicktime, ole2, and split extractors were also
improved.

Helper libraries perform the extraction. It is extendable by linking
against external extractors for additional file types.

The goal is to provide developers of indexing tools with a universal
library to obtain simple keywords to match against queries.
libextractor contains a shell command 'extract' that, similar to the
well-known 'file' command, can extract metadata from a file and print
the results to stdout.

The project site is http://savannah.gnu.org/projects/libextractor.

%package -n lib%{name}%{soname}
Summary:        Shared libraries for the package libextractor
Group:          System/Libraries
Requires:       lib%{name}_common%{common_soname} = %{version}
Provides:       %{name}1 = 0.5.3
Obsoletes:      %{name}1 < 0.5.3

%description -n lib%{name}%{soname}
This package contains the shared libraries for the package libextractor.

%package -n lib%{name}_common%{common_soname}
Summary:        Shared libraries for the package libextractor
Group:          System/Libraries

%description -n lib%{name}_common%{common_soname}
This package contains the shared libraries for the package libextractor.

%package -n lib%{name}-devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{soname} = %{version}

%description -n lib%{name}-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%lang_package

%prep
%setup -q -n "lib%{name}-%{version}"

%build
export CPPFLAGS="%{optflags} -D__STDC_CONSTANT_MACROS -I/usr/include/poppler"
export CXXFLAGS="%{optflags} -D__STDC_CONSTANT_MACROS -I/usr/include/poppler"
export CFLAGS="%{optflags} -D__STDC_CONSTANT_MACROS -I/usr/include/poppler"
%configure \
#    --enable-ffmpeg

find . -name Makefile | xargs sed -i -e 's|-L/usr/lib|-L/%{_libdir}|g'

make \
    STRIP=touch

%install
%makeinstall \
    STRIP=touch

rm %{buildroot}%{_libdir}/*.{la,a}
rm %{buildroot}%{_libdir}/lib%{name}/*.{la,a}

%find_lang lib%{name}

%post   -n lib%{name}%{soname} -p /sbin/ldconfig
%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%post   -n lib%{name}_common%{common_soname} -p /sbin/ldconfig
%postun -n lib%{name}_common%{common_soname} -p /sbin/ldconfig

%post -n lib%{name}-devel
%install_info --info-dir=%{_infodir} %{_infodir}/lib%{name}.info.gz

%postun -n lib%{name}-devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/lib%{name}.info.gz

%files lang -f lib%{name}.lang

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README TODO
%doc %{_mandir}/man1/*
%{_bindir}/extract
%dir %{_libdir}/lib%{name}
%{_libdir}/lib%{name}/libextractor_archive.so
%{_libdir}/lib%{name}/libextractor_deb.so
%{_libdir}/lib%{name}/libextractor_dvi.so
%{_libdir}/lib%{name}/libextractor_exiv2.so
%{_libdir}/lib%{name}/libextractor_flac.so
%{_libdir}/lib%{name}/libextractor_gif.so
#%{_libdir}/lib%{name}/libextractor_html.so
%{_libdir}/lib%{name}/libextractor_it.so
%if 0%{?suse_version} >= 1230
%{_libdir}/lib%{name}/libextractor_jpeg.so
%endif
%{_libdir}/lib%{name}/libextractor_man.so
%{_libdir}/lib%{name}/libextractor_mime.so
%{_libdir}/lib%{name}/libextractor_mpeg.so
%{_libdir}/lib%{name}/libextractor_nsf.so
%{_libdir}/lib%{name}/libextractor_nsfe.so
%{_libdir}/lib%{name}/libextractor_odf.so
%{_libdir}/lib%{name}/libextractor_ogg.so
%{_libdir}/lib%{name}/libextractor_ole2.so
%{_libdir}/lib%{name}/libextractor_png.so
%{_libdir}/lib%{name}/libextractor_ps.so
%{_libdir}/lib%{name}/libextractor_riff.so
%{_libdir}/lib%{name}/libextractor_rpm.so
%{_libdir}/lib%{name}/libextractor_s3m.so
%{_libdir}/lib%{name}/libextractor_sid.so
#%{_libdir}/lib%{name}/libextractor_thumbnailffmpeg.so
%{_libdir}/lib%{name}/libextractor_thumbnailgtk.so
%{_libdir}/lib%{name}/libextractor_tiff.so
%{_libdir}/lib%{name}/libextractor_wav.so
%{_libdir}/lib%{name}/libextractor_xm.so
%{_libdir}/lib%{name}/libextractor_zip.so

%files -n lib%{name}%{soname}
%defattr(-,root,root)
%{_libdir}/libextractor.so.%{soname}
%{_libdir}/libextractor.so.%{soname}.*

%files -n lib%{name}_common%{common_soname}
%defattr(-,root,root)
%{_libdir}/libextractor_common.so.%{common_soname}
%{_libdir}/libextractor_common.so.%{common_soname}.*

%files -n lib%{name}-devel
%defattr(-,root,root)
%doc %{_mandir}/man3/*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_infodir}/lib%{name}.info.gz

%changelog
* Thu Dec 19 2013 sleep_walker@suse.cz
- bump to 1.2
  * Increase select() timeout, handle timeout case better.
  * Required external installation of libltdl.
  * Check for presence of tidyNodeGetValue in libtidy.
  * Updated Dutch translation.
  * Fix build with libavcodec >= 54.25.0.
- removing libextractor-ffmpeg-2.0.patch as it is not needed anymore
* Sat Jul 27 2013 i@margueirte.su
- update version 1.1
  * xpdf plugin obsoleted
  * qt thumbnail plugin obsoleted
  * applefile plugin obsoleted
  * asf plugin obsoleted
  * elf plugin obsoleted
  * flv plugin obsoleted
  * mkv plugin obsoleted
  * mp3 plugin obsoleted (thus all the id3 plugins)
  * real plugin obsoleted
  * tar plugin obsoleted
  * see http://lists.gnu.org/archive/html/gnunet-svn/2012-08/msg00217.html
- html plugin disabled, 'coz we don't have htmltidy.
- jpeg plugin doesn't work for lower versions. (< 1230)
- gstreamer plugin disabled, 'coz it's experimental.
* Thu May 31 2012 Manfred.Tremmel@iiv.de
- ffmpeg calls are outdated, compile against ffmpeg_oldabi
* Thu Dec  1 2011 pascal.bleser@opensuse.org
- update to 0.6.3
- This release fixes various minor bugs, in particular better handling of
  malloc failures and more robust handling of malformed inputs in various
  plugins.
* Sun Mar 14 2010 toni@links2linux.de
- update to 0.6.1
- This release fixes a problem with LE not finding its plugins under
  certain conditions. It also fixes an IPC issue under FreeBSD which
  caused some plugins to not work.
* Thu Jan 14 2010 toni@links2linux.de
- update to 0.6.0
- new so-name ==> libextractor3
- renamed libextractor to extractor
- removed static library
- This release adds out-of-process execution for plugins and improves
  the quality and quantity of the extracted meta data for many formats.
- It breaks API compatibility.
* Tue Oct 20 2009 toni@links2linux.de
- update to 0.5.23
- This release adds support for librpm 4.7 and uses an external version of
  libexiv2 for improved and more up-to-date EXIV2 support.
* Sat Feb 21 2009 toni@links2linux.de
- update to 0.5.22
- added install-info macros, moved info pages to devel package
* Sun Nov  2 2008 toni@links2linux.de
- update to 0.5.21
* Tue Jul 15 2008 toni@links2linux.de
- update to 0.5.20c
* Sun Apr 27 2008 toni@links2linux.de
- update to 0.5.20b
* Tue Apr 15 2008 toni@links2linux.de
- update to 0.5.20a
* Sun Mar 23 2008 toni@links2linux.de
- update to 0.5.20
* Sun Jan 13 2008 toni@links2linux.de
- update to 0.5.19a
* Mon Jan  7 2008 toni@links2linux.de
- update to 0.5.19
* Sun Sep  2 2007 toni@links2linux.de
- buildOpenSUSE-10.3, fixed BuildRequires
* Mon Jun 25 2007 toni@links2linux.de
- initial build 0.5.18
